##  Deleting a Survey Run
To delete a survey run, follow these steps:
  1. Open the survey from the Manage Surveys section.
  2. From the three-dot menu at the top, click Show History. All previous survey runs are listed on the right-side panel.
  3. Hover over the survey run instance, and from the three-dot menu, click Delete.


![Deleting a Survey](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27502d2b7a4410148932ede03d7af3dc_LowRes.png)
Deleting a Survey Run
YesNo
Send
